@@ -789,7 +789,9 @@ the list should be unique."
 		 (thing   (cdr ml-elem)))
 	    (if (string-match regexp infoval)
 		;; we found a match, time to return
-		(setq rtnvalue thing
+		(setq rtnvalue (if (consp thing)
+				   (car thing)
+				 thing)
 		      mlist nil
 		      alist nil)
 	      ;; else we didn't find a match
